@@ -1,6 +1,9 @@
 # Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
 # SPDX-License-Identifier: Apache-2.0
+
+import abc
 from datetime import datetime
+import sys
 from typing import (
     TYPE_CHECKING,
     AbstractSet,
@@ -14,12 +17,21 @@ from typing import (
 )
 import uuid
 
+from .. import _repr
 from ..damlast.daml_lf_1 import TypeConName
 from ..damlast.lookup import parse_type_con_name
 from ..prim import LEDGER_STRING_REGEX, ContractData, ContractId, Party, to_parties
 from ..util.typing import safe_cast
 
+if sys.version_info >= (3, 8):
+    from typing import Final, final
+else:
+    from typing_extensions import Final, final
+
+
 __all__ = [
+    "ActAs",
+    "Admin",
     "ApplicationMeteringReport",
     "ArchiveEvent",
     "Boundary",
@@ -35,8 +47,11 @@ __all__ = [
     "ExerciseResponse",
     "ParticipantMeteringReport",
     "PartyInfo",
+    "ReadAs",
+    "Right",
     "SubmitResponse",
     "User",
+    "Version",
 ]
 
 
@@ -394,6 +409,18 @@ class CommandMeta:
             and self.act_as == other.act_as
         )
 
+    def __repr__(self) -> str:
+        s = []
+        if self.workflow_id is not None:
+            s.append(f"workflow_id={_repr.str(self.workflow_id)}")
+        if self.command_id is not None:
+            s.append(f"command_id={_repr.str(self.command_id )}")
+        if self.read_as is not None:
+            s.append(f"read_as={_repr.list(self.read_as)}")
+        if self.act_as is not None:
+            s.append(f"act_as={_repr.list(self.act_as)}")
+        return f"{self.__class__.__name__}({', '.join(s)})"
+
 
 class CreateEvent:
     """
@@ -590,8 +617,6 @@ SubmitResponse = Union[None, CreateEvent, ExerciseResponse]
 class User:
     """
     Full information about a ``User``.
-
-    Note: This is part of a Daml 2.x pre-release API and is subject to change.
     """
 
     __slots__ = ("id", "primary_party")
@@ -603,6 +628,58 @@ class User:
         self.primary_party = primary_party
 
 
+class Right(abc.ABC):
+    """
+    Information about an individual right for a :class:`User`.
+    """
+
+    def __setattr__(self, key, value):
+        """
+        Overridden to make Right objects read-only.
+        """
+        raise AttributeError
+
+
+@final
+class ReadAs(Right):
+    _slots__: Final = ("party",)
+    __match_args__: Final = ("party",)
+
+    party: Party
+
+    def __init__(self, __party: Party):
+        object.__setattr__(self, "party", __party)
+
+    def __repr__(self) -> str:
+        return f"ReadAs({self.party!r})"
+
+
+@final
+class ActAs(Right):
+    __slots__: Final = ("party",)
+    __match_args__: Final = ("party",)
+
+    party: Party
+
+    def __init__(self, __party: Party):
+        object.__setattr__(self, "party", __party)
+
+    def __repr__(self) -> str:
+        return f"ActAs({self.party!r})"
+
+
+@final
+class _Admin(Right):
+    __slots__: Final = ()
+    __match_args__: Final = ()
+
+    def __repr__(self) -> str:
+        return "Admin"
+
+
+Admin = _Admin()
+
+
 class PartyInfo:
     """
     Full information about a ``Party``.
@@ -641,6 +718,39 @@ class PartyInfo:
         return self._is_local
 
 
+class Version:
+    __slots__ = ("version", "features")
+
+    version: "Final[str]"  # type: ignore
+    features: "Final[VersionFeatures]"  # type: ignore
+
+    def __init__(self, version: str, features: "VersionFeatures"):
+        object.__setattr__(self, "version", version)
+        object.__setattr__(self, "features", features)
+
+
+class VersionFeatures:
+    __slots__ = ("user_management",)
+
+    user_management: "Final[VersionUserManagementFeature]"  # type: ignore
+
+    def __init__(self, user_management: "VersionUserManagementFeature"):
+        object.__setattr__(self, "user_management", user_management)
+
+
+class VersionUserManagementFeature:
+    __slots__ = ("supported", "max_rights_per_user", "max_users_page_size")
+
+    supported: "Final[bool]"  # type: ignore
+    max_rights_per_user: "Final[int]"  # type: ignore
+    max_users_page_size: "Final[int]"  # type: ignore
+
+    def __init__(self, supported: bool, max_rights_per_user: int, max_users_page_size: int):
+        object.__setattr__(self, "supported", supported)
+        object.__setattr__(self, "max_rights_per_user", max_rights_per_user)
+        object.__setattr__(self, "max_users_page_size", max_users_page_size)
+
+
 class ParticipantMeteringReport:
     __slots__ = ("report_generation_time", "participant_id", "is_final", "application_reports")
     report_generation_time: datetime
